@@ -23,6 +23,12 @@ FAILEDOPERATION = 'FailedOperation'
 # 年龄限制无法使用电子签服务，请联系客服咨询处理。
 FAILEDOPERATION_AGENOTACHIEVENORMALLEGAL = 'FailedOperation.AgeNotAchieveNormalLegal'
 
+# 授权认证已经被删除了
+FAILEDOPERATION_AUTHORIZATIONINFOHASBEENDELETED = 'FailedOperation.AuthorizationInfoHasBeenDeleted'
+
+# 套餐余额不足。
+FAILEDOPERATION_BALANCENOTENOUGH = 'FailedOperation.BalanceNotEnough'
+
 # 签署流程已有关联文档，请检查参数修改后重试。
 FAILEDOPERATION_FLOWHASDOCUMENT = 'FailedOperation.FlowHasDocument'
 
@@ -95,15 +101,24 @@ INTERNALERROR_CALLOPENCLOUDAPIERROR = 'InternalError.CallOpenCloudApiError'
 # 回调错误。
 INTERNALERROR_CALLBACK = 'InternalError.Callback'
 
+# 文件上传到文件存储失败
+INTERNALERROR_COS = 'InternalError.Cos'
+
 # 数据库异常。
 INTERNALERROR_DB = 'InternalError.Db'
 
 # 数据库连接出错。
 INTERNALERROR_DBCONNECTION = 'InternalError.DbConnection'
 
+# 数据已经被删除
+INTERNALERROR_DBDATADELETED = 'InternalError.DbDataDeleted'
+
 # 数据库新增记录出错。
 INTERNALERROR_DBINSERT = 'InternalError.DbInsert'
 
+# 没有找到传递的数据，请检查核对参数，再重新调用
+INTERNALERROR_DBNOROWFOUND = 'InternalError.DbNoRowFound'
+
 # 内部错误,数据库查询失败,请稍后重试。
 INTERNALERROR_DBREAD = 'InternalError.DbRead'
 
@@ -122,6 +137,12 @@ INTERNALERROR_ENCRYPTION = 'InternalError.Encryption'
 # Json序列化失败。
 INTERNALERROR_JSONMARSHAL = 'InternalError.JsonMarshal'
 
+# 数据json反编译失败
+INTERNALERROR_JSONUNMARSHAL = 'InternalError.JsonUnmarshal'
+
+# 消息队列失败
+INTERNALERROR_MQ = 'InternalError.Mq'
+
 # Pdf错误。
 INTERNALERROR_PDF = 'InternalError.Pdf'
 
@@ -137,6 +158,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 不合法的签署人类型，请检查后重试。
 INVALIDPARAMETER_APPROVERTYPE = 'InvalidParameter.ApproverType'
 
+# 不合法的授权方式，请检查修改后重试。
+INVALIDPARAMETER_AUTHORIZATIONTYPE = 'InvalidParameter.AuthorizationType'
+
 # 不合法的业务id，请检查是否传递，检查是否超过接口上限数量，并在修改后重试。
 INVALIDPARAMETER_BUSINESSID = 'InvalidParameter.BusinessId'
 
@@ -161,12 +185,18 @@ INVALIDPARAMETER_CLIENTTOKEN = 'InvalidParameter.ClientToken'
 # 不合法的控件所在文件序号，请检查文件资源与控件的对应关系，并在修改后重试。
 INVALIDPARAMETER_COMPONENTFILEINDEX = 'InvalidParameter.ComponentFileIndex'
 
+# 控件非法
+INVALIDPARAMETER_COMPONENTINVALID = 'InvalidParameter.ComponentInvalid'
+
 # 不合法的控件页码，请与文件资源检查，并在修改后重试。
 INVALIDPARAMETER_COMPONENTPAGE = 'InvalidParameter.ComponentPage'
 
 # 不合法的控件大小或坐标，请检查控件坐标，大小是否合理，并在修改后重试。
 INVALIDPARAMETER_COMPONENTPOSITION = 'InvalidParameter.ComponentPosition'
 
+# 控件类型非法
+INVALIDPARAMETER_COMPONENTTYPE = 'InvalidParameter.ComponentType'
+
 # 控件的类型与输入值不匹配，请检查参数修改后重试。
 INVALIDPARAMETER_COMPONENTTYPENOMATCHVALUE = 'InvalidParameter.ComponentTypeNoMatchValue'
 
@@ -194,6 +224,12 @@ INVALIDPARAMETER_EMPTYPARAMS = 'InvalidParameter.EmptyParams'
 # 不合法的EndPoint，请检查修改后重试。
 INVALIDPARAMETER_ENDPOINT = 'InvalidParameter.EndPoint'
 
+# 文件类型不合法
+INVALIDPARAMETER_FILETYPE = 'InvalidParameter.FileType'
+
+# 不合法的合同过期时间
+INVALIDPARAMETER_FLOWAPPROVERDEADLINE = 'InvalidParameter.FlowApproverDeadline'
+
 # 不合法的签署流程回调链接，请修改后重试。
 INVALIDPARAMETER_FLOWCALLBACKURL = 'InvalidParameter.FlowCallbackUrl'
 
@@ -203,6 +239,9 @@ INVALIDPARAMETER_FLOWDEADLINE = 'InvalidParameter.FlowDeadLine'
 # 不合法的签署流程描述，请修改后重试。
 INVALIDPARAMETER_FLOWDESCRIPTION = 'InvalidParameter.FlowDescription'
 
+# 文件ID不合法
+INVALIDPARAMETER_FLOWFILEIDS = 'InvalidParameter.FlowFileIds'
+
 # 不合法的签署流程名称，请修改后重试。
 INVALIDPARAMETER_FLOWNAME = 'InvalidParameter.FlowName'
 
@@ -254,6 +293,12 @@ INVALIDPARAMETER_INVALIDROLENAME = 'InvalidParameter.InvalidRoleName'
 # 实名认证渠道不正确。
 INVALIDPARAMETER_INVALIDVERIFYCHANNEL = 'InvalidParameter.InvalidVerifyChannel'
 
+# 不合法的跳转链接，请联系电子签客服添加链接白名单。
+INVALIDPARAMETER_JUMPURL = 'InvalidParameter.JumpUrl'
+
+# 关键字格式错误或者不存在。
+INVALIDPARAMETER_KEYWORD = 'InvalidParameter.Keyword'
+
 # Limit参数超出最大限制
 INVALIDPARAMETER_LIMIT = 'InvalidParameter.Limit'
 
@@ -305,6 +350,12 @@ INVALIDPARAMETER_SEALID = 'InvalidParameter.SealId'
 # 参数包含有敏感词
 INVALIDPARAMETER_SENSITIVE = 'InvalidParameter.Sensitive'
 
+# 上传的文件包含敏感（不合规）的内容，请确认。
+INVALIDPARAMETER_SENSITIVEFILECONTENT = 'InvalidParameter.SensitiveFileContent'
+
+# 参数错误,暂不支持该种签署控件类型
+INVALIDPARAMETER_SIGNCOMPONENTTYPE = 'InvalidParameter.SignComponentType'
+
 # 签署控件参数不合法，请检查后重试。
 INVALIDPARAMETER_SIGNCOMPONENTS = 'InvalidParameter.SignComponents'
 
@@ -374,6 +425,12 @@ MISSINGPARAMETER_FLOWID = 'MissingParameter.FlowId'
 # 未找到关键字配置信息，请检查控件传参，检查文件资源配置，并在修改后重试。
 MISSINGPARAMETER_KEYWORD = 'MissingParameter.KeyWord'
 
+# 参数缺失，企业名称和统一信用代码不能同时为空。
+MISSINGPARAMETER_ORGNAMEORUNIFORMSOCIALCREDITCODE = 'MissingParameter.OrgNameOrUniformSocialCreditCode'
+
+# 缺少机构ID参数。
+MISSINGPARAMETER_ORGANIZATIONID = 'MissingParameter.OrganizationId'
+
 # 缺少签署二维码id，请检查后重试。
 MISSINGPARAMETER_QRCODEID = 'MissingParameter.QrCodeId'
 
@@ -398,6 +455,9 @@ MISSINGPARAMETER_USERID = 'MissingParameter.UserId'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 当前用户创建的数据已经存在了，不需要重复调用。
+OPERATIONDENIED_ALREADYHAS = 'OperationDenied.AlreadyHas'
+
 # 签署人设置与模板中签署人配置信息不一致，请检查模板修改参数后重试。
 OPERATIONDENIED_APPROVERNOMATCHTEMPLATE = 'OperationDenied.ApproverNoMatchTemplate'
 
@@ -455,6 +515,9 @@ OPERATIONDENIED_FORBID = 'OperationDenied.Forbid'
 # 签署人年龄限制无法使用电子签服务。
 OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'
 
+# 子企业的license已经过期
+OPERATIONDENIED_LICENSEHASEXPIRED = 'OperationDenied.LicenseHasExpired'
+
 # 资源id超过使用上限限制，请联系客服了解规则，并在修改后重试。
 OPERATIONDENIED_MANYRESOURCEID = 'OperationDenied.ManyResourceId'
 
@@ -503,6 +566,9 @@ OPERATIONDENIED_OPERATORHASNOPERMISSION = 'OperationDenied.OperatorHasNoPermissi
 # 此社会信用编码未查询到结果，请检查后重试。
 OPERATIONDENIED_ORGUNIFORMSOCIALCREDITCODEERR = 'OperationDenied.OrgUniformSocialCreditCodeErr'
 
+# 企业注销中
+OPERATIONDENIED_ORGANIZATIONCLOSING = 'OperationDenied.OrganizationClosing'
+
 # 企业未激活。
 OPERATIONDENIED_ORGANIZATIONNOTACTIVATED = 'OperationDenied.OrganizationNotActivated'
 
@@ -542,6 +608,9 @@ OPERATIONDENIED_SERVERSIGNNOSUPPORTSIGNATURE = 'OperationDenied.ServerSignNoSupp
 # 子企业暂未加入。
 OPERATIONDENIED_SUBORGNOTJOIN = 'OperationDenied.SubOrgNotJoin'
 
+# 您加入企业的员工加入申请正在审核中。
+OPERATIONDENIED_USERNOAUDIT = 'OperationDenied.UserNoAudit'
+
 # 用户不归属于当前企业，无法操作，请检查后重试。
 OPERATIONDENIED_USERNOTINORGANIZATION = 'OperationDenied.UserNotInOrganization'
 
